@@ -8,16 +8,17 @@ use vars '@EXPORT_OK';
 use Dancer::Template;
 use Dancer::ModuleLoader;
 use Dancer::FileUtils 'path';
-use Carp 'confess';
+use Carp;
+
+use Encode;
 
 @EXPORT_OK = qw(setting mime_types);
 
-# singleton for storing settings
-my $SETTINGS = {
+my $SETTINGS = {};
+
+# mergeable settings
+my %MERGEABLE = map { ($_ => 1) } qw( plugins handlers );
 
-    # user defined mime types
-    mime_types => {},
-};
 sub settings {$SETTINGS}
 
 my $setters = {
@@ -60,30 +61,81 @@ my $setters = {
             );
         }
     },
+    traces => sub {
+        my ($setting, $traces) = @_;
+        $Carp::Verbose = $traces ? 1 : 0;
+    },
 };
 
+my $normalizers = {
+    charset => sub {
+        my ($setting, $charset) = @_;
+        length($charset || '')
+          or return $charset;
+        my $encoding = Encode::find_encoding($charset);
+        defined $encoding
+          or croak "Charset defined in configuration is wrong : couldn't identify '$charset'";
+        my $name = $encoding->name;
+        # Perl makes a distinction between the usual perl utf8, and the strict
+        # utf8 charset. But we don't want to make this distinction
+        $name eq 'utf-8-strict'
+          and $name = 'utf-8';
+        return $name;
+    },
+};
+
+sub mime_types {
+    carp "DEPRECATED: use 'mime_type' from Dancer.pm";
+    my $mime = Dancer::MIME->instance();
+    if    (scalar(@_)==2) { $mime->add_mime_type(@_) }
+    elsif (scalar(@_)==1) { $mime->mime_type_for(@_) }
+    else                  { $mime->aliases           }
+}
+
+sub normalize_setting {
+    my ($class, $setting, $value) = @_;
+
+    $value = $normalizers->{$setting}->($setting, $value)
+      if exists $normalizers->{$setting};
+
+    return $value;
+}
+
 # public accessor for get/set
 sub setting {
     my ($setting, $value) = @_;
 
-    # run the hook if setter
-    $setters->{$setting}->(@_)
-      if (@_ == 2) && defined $setters->{$setting};
-
-    # setter/getter
-    (@_ == 2)
-      ? $SETTINGS->{$setting} = $value
-      : $SETTINGS->{$setting};
+    if (@_ == 2) {
+        $value = _set_setting($setting, $value);
+        _trigger_hooks($setting, $value);
+        return $value;
+    }
+    else {
+        return _get_setting($setting);
+    }
 }
 
-sub mime_types {
-    my ($ext, $content_type) = @_;
-    $SETTINGS->{mime_types} ||= {};
-    return $SETTINGS->{mime_types} if @_ == 0;
+sub _trigger_hooks {
+    my ($setting, $value) = @_;
 
-    return (@_ == 2)
-      ? $SETTINGS->{mime_types}{$ext} = $content_type
-      : $SETTINGS->{mime_types}{$ext};
+    $setters->{$setting}->(@_) if defined $setters->{$setting};
+}
+
+sub _set_setting {
+    my ($setting, $value) = @_;
+
+    return unless @_ == 2;
+
+    # normalize the value if needed
+    $value = Dancer::Config->normalize_setting($setting, $value);
+    $SETTINGS->{$setting} = $value;
+    return $value;
+}
+
+sub _get_setting {
+    my $setting = shift;
+
+    return $SETTINGS->{$setting};
 }
 
 sub conffile { path(setting('confdir') || setting('appdir'), 'config.yml') }
@@ -108,7 +160,6 @@ sub load {
     confess "Configuration file found but YAML is not installed"
       unless Dancer::ModuleLoader->load('YAML');
 
-    load_default_settings();
     load_settings_from_yaml(conffile);
 
     my $env = environment_file;
@@ -124,14 +175,26 @@ sub load {
 sub load_settings_from_yaml {
     my ($file) = @_;
 
-    my $config = YAML::LoadFile($file)
-      or confess "Unable to parse the configuration file: $file";
+    my $config;
+
+    eval { $config = YAML::LoadFile($file) };
+    if (my $err = $@ || (!$config)) {
+        confess "Unable to parse the configuration file: $file: $@";
+    }
+
+    for my $key (keys %{$config}) {
+        if ($MERGEABLE{$key}) {
+            my $setting = setting($key);
+            $setting->{$_} = $config->{$key}{$_} for keys %{$config->{$key}};
+        }
+        else {
+            _set_setting($key, $config->{$key});
+        }
+    }
 
-    @{$SETTINGS}{keys %$config} = values %$config;
     return scalar(keys %$config);
 }
 
-
 sub load_default_settings {
     $SETTINGS->{server}       ||= $ENV{DANCER_SERVER}       || '0.0.0.0';
     $SETTINGS->{port}         ||= $ENV{DANCER_PORT}         || '3000';
@@ -142,11 +205,13 @@ sub load_default_settings {
     $SETTINGS->{apphandler}   ||= $ENV{DANCER_APPHANDLER}   || 'Standalone';
     $SETTINGS->{warnings}     ||= $ENV{DANCER_WARNINGS}     || 0;
     $SETTINGS->{auto_reload}  ||= $ENV{DANCER_AUTO_RELOAD}  || 0;
+    $SETTINGS->{traces}       ||= $ENV{DANCER_TRACES}       || 0;
     $SETTINGS->{environment} 
       ||= $ENV{DANCER_ENVIRONMENT}
       || $ENV{PLACK_ENV}
       || 'development';
 
+    setting $_ => {} for keys %MERGEABLE;
     setting template        => 'simple';
     setting import_warnings => 1;
 }
@@ -210,9 +275,26 @@ Default value is 'text/html'.
 
 =head2 charset (string)
 
-The default charset of outgoing content. Unicode bodies in HTTP
-responses of C<text/*> types will be encoded to this charset. Also,
-C<charset=> item will be added to Content-Type response header.
+This setting does 3 things:
+
+=over
+
+=item *
+
+It sets the default charset of outgoing content. C<charset=> item will be
+added to Content-Type response header.
+
+=item *
+
+It makes Unicode bodies in HTTP responses of C<text/*> types to be encoded to
+this charset.
+
+=item *
+
+It also indicates to Dancer in which charset the static files and templates are
+encoded.
+
+=back
 
 Default value is empty which means don't do anything. HTTP responses
 without charset will be interpreted as ISO-8859-1 by most clients.
@@ -244,6 +326,11 @@ a matching template in the directory $appdir/views/layout.
 
 If set to true, tells Dancer to consider all warnings as blocking errors.
 
+=head2 traces (boolean)
+
+If set to true, Dancer will display full stack traces when a warning or a die
+occurs. (Internally sets Carp::Verbose). Default to false.
+
 =head2 log (enum)
 
 Tells which log messages should be actullay logged. Possible values are
