@@ -117,15 +117,6 @@ sub render_response {
     my $content = $response->{content};
     unless (ref($content) eq 'GLOB') {
 
-        # when the request is considered as ajax,
-        # we set the content type to text/xml
-        if (   Dancer::SharedData->request
-            && Dancer::SharedData->request->is_ajax)
-        {
-            $response->header(
-                'Content-Type' => 'text/xml; charset=UTF-8');
-        }
-
         my $charset = setting('charset');
         my $ctype   = $response->header('Content-Type');
 
