@@ -67,6 +67,12 @@ sub set {
     $CURRENT = shift;
 }
 
+# FIXME this whole class needs to be rewritten
+sub set_current_content {
+    $CURRENT->{content} = $_[0] 
+        if defined $CURRENT;
+}
+
 sub content {
     my $current = _get_object(shift);
     my $content = shift;
@@ -144,6 +150,7 @@ sub halted {
     $current && $current->{halted}
 }
 
+
 sub header {
     my $current = _get_object(shift);
     my $header = shift;
