@@ -77,8 +77,10 @@ sub match {
           . "/");
 
     my @values = $path =~ $self->{_compiled_regexp};
-    Dancer::Logger::core("  --> got @values") if @values;
-
+    Dancer::Logger::core("  --> got ".
+        map { defined $_ ? $_ : 'undef' } @values) 
+        if @values;
+    
     # if some named captures found, return captures
     # no warnings is for perl < 5.10
     if (my %captures =
@@ -93,6 +95,14 @@ sub match {
 
     return unless @values;
 
+    # save the route pattern that matched
+    # TODO : as soon as we have proper Dancer::Internal, we should remove 
+    # that, it's just a quick hack for plugins to access the matching 
+    # pattern.
+    # NOTE: YOU SHOULD NOT USE THAT, OR IF YOU DO, YOU MUST KNOW
+    # IT WILL MOVE VERY SOON
+    $request->{_route_pattern} = $self->pattern;
+
     # named tokens
     my @tokens = @{$self->{_params} || []};
 
@@ -145,8 +155,25 @@ sub run {
     my $content  = $self->execute();
     my $response = Dancer::Response->current;
 
-    if ($response->{pass}) {
+    if ( $response->is_forwarded ) {
+        my $new_req = Dancer::Request->new_for_request(
+            $request->method,
+            $response->{forward},
+            $request->params,
+            $request->body,
+            $request->headers,
+        );
 
+        my $marshalled = Dancer::Handler->handle_request($new_req);
+
+        return Dancer::Response->new(
+            status  => $marshalled->[0],
+            headers => $marshalled->[1],
+            content => @{ $marshalled->[2] },
+        );
+    }
+
+    if ($response->has_passed) {
         if ($self->next) {
             my $next_route = $self->find_next_matching_route($request);
             return $next_route->run($request);
@@ -164,8 +191,8 @@ sub run {
     $content = '' if $request->is_head;
 
     # init response headers
-    my $ct = $response->{content_type} || setting('content_type');
-    my $st = $response->{status}       || 200;
+    my $ct = $response->content_type() || setting('content_type');
+    my $st = $response->status()       || 200;
     my $headers = [];
     push @$headers, @{$response->headers_to_array};
 
@@ -179,7 +206,6 @@ sub run {
         status       => $st,
         headers      => $headers,
         content      => $content,
-        content_type => $ct,
     );
 }
 
@@ -277,9 +303,9 @@ sub _build_regexp_from_string {
 
     # look for route with params (/hello/:foo)
     if ($pattern =~ /:/) {
-        @params = $pattern =~ /:([^\/\.]+)/g;
+        @params = $pattern =~ /:([^\/\.\?]+)/g;
         if (@params) {
-            $pattern =~ s/(:[^\/\.]+)/\(\[\^\/\]\+\)/g;
+            $pattern =~ s/(:[^\/\.\?]+)/\(\[\^\/\]\+\)/g;
             $capture = 1;
         }
     }
