@@ -2,6 +2,7 @@ package Dancer::Serializer::YAML;
 
 use strict;
 use warnings;
+use Carp;
 use Dancer::ModuleLoader;
 use base 'Dancer::Serializer::Abstract';
 
@@ -25,7 +26,7 @@ sub loaded { Dancer::ModuleLoader->load('YAML') }
 
 sub init {
     my ($self) = @_;
-    die 'YAML is needed and is not installed'
+    croak 'YAML is needed and is not installed'
       unless $self->loaded;
 }
 
